==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/Stepper.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { Step } from "./Step";
import { StepperOrientation_$type } from "./StepperOrientation";
import { StepperStepType_$type } from "./StepperStepType";
import { Direction_$type } from "./Direction";
import { StepperTitlePosition_$type } from "./StepperTitlePosition";
import { ActiveStepChangingArgsEventArgs } from "./ActiveStepChangingArgsEventArgs";
import { ActiveStepChangedArgsEventArgs } from "./ActiveStepChangedArgsEventArgs";
/**
 * @hidden
 */
var Stepper = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stepper, _super);
    function Stepper() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.h = new WCNativeHelper();
        _this.l = null;
        _this.activeStepChanging = null;
        _this.activeStepChanged = null;
        return _this;
    }
    Object.defineProperty(Stepper.prototype, "i", {
        get: function () {
            return this.h;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "nativeElement", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.h.n = this.l;
        },
        enumerable: false,
        configurable: true
    });
    Stepper.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Stepper.prototype, "a", {
        get: function () {
            var ret_ = this.i.l("steps", function (a) { return new Step(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.u("steps", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "e", {
        get: function () {
            var ret_ = this.i.m("orientation");
            ret_ = enumGetBox(StepperOrientation_$type, EnumUtil.getEnumValue(StepperOrientation_$type, this.i.f(StepperOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(StepperOrientation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(StepperOrientation_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.i.u("orientation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "f", {
        get: function () {
            var ret_ = this.i.m("stepType");
            ret_ = enumGetBox(StepperStepType_$type, EnumUtil.getEnumValue(StepperStepType_$type, this.i.f(StepperStepType_$type, ret_)));
            return EnumUtil.getEnumValue(StepperStepType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(StepperStepType_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.i.u("stepType", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "k", {
        get: function () {
            var ret_ = this.i.m("linear");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.u("linear", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "j", {
        get: function () {
            var ret_ = this.i.m("contentTop");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.u("contentTop", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "d", {
        get: function () {
            var ret_ = this.i.m("dir");
            ret_ = enumGetBox(Direction_$type, EnumUtil.getEnumValue(Direction_$type, this.i.f(Direction_$type, ret_)));
            return EnumUtil.getEnumValue(Direction_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(Direction_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.i.u("dir", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "g", {
        get: function () {
            var ret_ = this.i.m("titlePosition");
            ret_ = enumGetBox(StepperTitlePosition_$type, EnumUtil.getEnumValue(StepperTitlePosition_$type, this.i.f(StepperTitlePosition_$type, ret_)));
            return EnumUtil.getEnumValue(StepperTitlePosition_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(StepperTitlePosition_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.i.u("titlePosition", value_);
        },
        enumerable: false,
        configurable: true
    });
    Stepper.prototype.activeStepChangingChanged = function () {
        var _this = this;
        if (this.activeStepChanging != null) {
            this.i.q("activeStepChanging", function (a) { return _this.activeStepChanging(_this, ActiveStepChangingArgsEventArgs.b(a)); });
        }
        else {
            this.i.t("activeStepChanging");
        }
    };
    Stepper.prototype.activeStepChangedChanged = function () {
        var _this = this;
        if (this.activeStepChanged != null) {
            this.i.q("activeStepChanged", function (a) { return _this.activeStepChanged(_this, ActiveStepChangedArgsEventArgs.b(a)); });
        }
        else {
            this.i.t("activeStepChanged");
        }
    };
    Stepper.prototype.p = function () {
        this.nativeElement.connectedCallback();
    };
    Stepper.prototype.q = function (a) {
        this.nativeElement.navigateTo(this.i.h(a));
    };
    Stepper.prototype.r = function () {
        this.nativeElement.next();
    };
    Stepper.prototype.s = function () {
        this.nativeElement.prev();
    };
    Stepper.prototype.t = function () {
        this.nativeElement.reset();
    };
    Stepper.$t = markType(Stepper, 'Stepper', BaseElement.$);
    return Stepper;
}(BaseElement));
export { Stepper };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/Stepper.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { Step } from "./Step";
import { StepperOrientation_$type } from "./StepperOrientation";
import { StepperStepType_$type } from "./StepperStepType";
import { Direction_$type } from "./Direction";
import { StepperTitlePosition_$type } from "./StepperTitlePosition";
import { ActiveStepChangingArgsEventArgs } from "./ActiveStepChangingArgsEventArgs";
import { ActiveStepChangedArgsEventArgs } from "./ActiveStepChangedArgsEventArgs";
/**
 * @hidden
 */
var Stepper = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stepper, _super);
    function Stepper() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.h = new WCNativeHelper();
        _this.l = null;
        _this.activeStepChanging = null;
        _this.activeStepChanged = null;
        return _this;
    }
    Object.defineProperty(Stepper.prototype, "i", {
        get: function () {
            return this.h;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "nativeElement", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.h.o = this.l;
        },
        enumerable: false,
        configurable: true
    });
    Stepper.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Stepper.prototype, "a", {
        get: function () {
            var ret_ = this.i.m("steps", function (a) { return new Step(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.v("steps", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "e", {
        get: function () {
            var ret_ = this.i.n("orientation");
            ret_ = enumGetBox(StepperOrientation_$type, EnumUtil.getEnumValue(StepperOrientation_$type, this.i.f(StepperOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(StepperOrientation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(StepperOrientation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("orientation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "f", {
        get: function () {
            var ret_ = this.i.n("stepType");
            ret_ = enumGetBox(StepperStepType_$type, EnumUtil.getEnumValue(StepperStepType_$type, this.i.f(StepperStepType_$type, ret_)));
            return EnumUtil.getEnumValue(StepperStepType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(StepperStepType_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("stepType", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "k", {
        get: function () {
            var ret_ = this.i.n("linear");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.v("linear", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "j", {
        get: function () {
            var ret_ = this.i.n("contentTop");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.v("contentTop", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "d", {
        get: function () {
            var ret_ = this.i.n("dir");
            ret_ = enumGetBox(Direction_$type, EnumUtil.getEnumValue(Direction_$type, this.i.f(Direction_$type, ret_)));
            return EnumUtil.getEnumValue(Direction_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(Direction_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("dir", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Stepper.prototype, "g", {
        get: function () {
            var ret_ = this.i.n("titlePosition");
            ret_ = enumGetBox(StepperTitlePosition_$type, EnumUtil.getEnumValue(StepperTitlePosition_$type, this.i.f(StepperTitlePosition_$type, ret_)));
            return EnumUtil.getEnumValue(StepperTitlePosition_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(StepperTitlePosition_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("titlePosition", value_);
        },
        enumerable: false,
        configurable: true
    });
    Stepper.prototype.activeStepChangingChanged = function () {
        var _this = this;
        if (this.activeStepChanging != null) {
            this.i.r("activeStepChanging", function (a) { return _this.activeStepChanging(_this, ActiveStepChangingArgsEventArgs.b(a)); });
        }
        else {
            this.i.u("activeStepChanging");
        }
    };
    Stepper.prototype.activeStepChangedChanged = function () {
        var _this = this;
        if (this.activeStepChanged != null) {
            this.i.r("activeStepChanged", function (a) { return _this.activeStepChanged(_this, ActiveStepChangedArgsEventArgs.b(a)); });
        }
        else {
            this.i.u("activeStepChanged");
        }
    };
    Stepper.prototype.p = function () {
        this.nativeElement.connectedCallback();
    };
    Stepper.prototype.q = function (a) {
        this.nativeElement.navigateTo(this.i.i(a));
    };
    Stepper.prototype.r = function () {
        this.nativeElement.next();
    };
    Stepper.prototype.s = function () {
        this.nativeElement.prev();
    };
    Stepper.prototype.t = function () {
        this.nativeElement.reset();
    };
    Stepper.$t = markType(Stepper, 'Stepper', BaseElement.$);
    return Stepper;
}(BaseElement));
export { Stepper };
